// xonix.cpp  -  main game file

#include "xonix.h"


// PROTOTYPES

void DrawEverything();


// FUNCTIONS //////////////////////////////////////////////////

// WINMAIN ////////////////////////////////////////////////////

LRESULT CALLBACK WindowProc(HWND hwnd, 
						    UINT msg, 
                            WPARAM wparam, 
                            LPARAM lparam)
{	// this is the main message handler of the system
	
	PAINTSTRUCT	ps;			// used in WM_PAINT
	HDC			hdc;		// handle to a device context

	switch(msg)								// what is the message 
	{
		case WM_CREATE:						// do initialization stuff here
			return(0);
			break;

		case WM_PAINT:
			hdc = BeginPaint(hwnd,&ps);		// start painting
			// the window is now validated 
			EndPaint(hwnd,&ps);				// end painting
			return(0);
			break;

		case WM_DESTROY: 
			PostQuitMessage(0);				// kill the application
			return(0);
			break;

		default:
			break;
	}

	// process any messages that we didn't take care of 
	return (DefWindowProc(hwnd, msg, wparam, lparam));

} // end WinProc


///////////////////////////////////////////////////////////////

int WINAPI WinMain(	HINSTANCE hinstance,
					HINSTANCE hprevinstance,
					LPSTR lpcmdline,
					int ncmdshow)
{	// this is the winmain function

	WNDCLASS winclass;	// this will hold the class we create
	HWND	 hwnd;		// generic window handle
	MSG		 msg;		// generic message

	// first fill in the window class stucture
	winclass.style			= CS_DBLCLKS | CS_OWNDC | 
							  CS_HREDRAW | CS_VREDRAW;
	winclass.lpfnWndProc	= WindowProc;
	winclass.cbClsExtra		= 0;
	winclass.cbWndExtra		= 0;
	winclass.hInstance		= hinstance;
	winclass.hIcon			= LoadIcon(NULL, IDI_APPLICATION);
	winclass.hCursor		= LoadCursor(NULL, IDC_ARROW);
	winclass.hbrBackground	= (HBRUSH)GetStockObject(BLACK_BRUSH);
	winclass.lpszMenuName	= NULL; 
	winclass.lpszClassName	= WINDOW_CLASS_NAME;
	
	if (!RegisterClass(&winclass))					// register the window class
		return(0);

	// create the window, note the use of WS_POPUP
	if (!(hwnd = CreateWindow(WINDOW_CLASS_NAME,    // class
				 "WIN3D Game Console",				// title
				 WS_POPUP | WS_VISIBLE,
				 0,0,								// initial x,y
   				 GetSystemMetrics(SM_CXSCREEN),		// intial width
				 GetSystemMetrics(SM_CYSCREEN),		// initial height
				 NULL,								// handle to parent 
				 NULL,								// handle to menu
				 hinstance,							// instance
				 NULL)))							// creation parms
		return(0);

	ShowCursor(FALSE);					// hide mouse

	// save the window handle and instance in a global
	main_window_handle = hwnd;
	main_instance      = hinstance;

	Game_Init();						// perform all game console specific initialization

	while(1)							// enter main event loop
	{
		if (PeekMessage(&msg,NULL,0,0,PM_REMOVE))
		{ 
			
			if (msg.message == WM_QUIT)	// test if this is a quit
			   break;
			TranslateMessage(&msg);		// translate any accelerator keys
			DispatchMessage(&msg);		// send the message to the window proc
		}
		Game_Main();					// main game processing goes here
	}

	Game_Shutdown();					// shutdown game and release all resources
	ShowCursor(TRUE);					// show mouse
	return(msg.wParam);					// return to Windows like this

} // end WinMain


// T3DX GAME PROGRAMMING CONSOLE FUNCTIONS ////////////////////

int Game_Init(void *parms)		// this function is where you do all the game initialization 
{

	int i;					// general-purpose counter

	DSound_Init();			// initialize directsound
	DMusic_Init();			// initialize directmusic

	// load in the digital sound
	sound[WIN_SOUND] = DSound_Load_WAV("sound\\win.wav");
	sound[BONUS_SOUND] = DSound_Load_WAV("sound\\bonus.wav");
	sound[DEATH_SOUND] = DSound_Load_WAV("sound\\death.wav");

	// load the midi segments for levels + pause and win game states
	for (i = 0; i < NUM_LEVELS + 2; i++)
	{
		sprintf(buffer, "midi\\level%d.mid", i);	// build up string name
		midiID[i] = DMusic_Load_MIDI(buffer);		// load midi file
	}

	return(1);	// return success

} // end Game_Init


///////////////////////////////////////////////////////////////

int Game_Shutdown(void *parms)	// this function is where you shutdown your game and
{								// release all resources that you allocated

	DSound_Stop_All_Sounds();	// stop all sounds
	DSound_Delete_All_Sounds();	// delete all sounds
	DSound_Shutdown();			// shutdown directsound
	DMusic_Delete_All_MIDI();	// delete all the music
	DMusic_Shutdown();			// shutdown directmusic

	return(1);					// return success

} // end Game_Shutdown


///////////////////////////////////////////////////////////////

void GenerateBonuses()
{
	int i = rand() % numBugs;		// one of the bugs will leave a bonus

	if (rand() % 3)					// with probability 2/3 leave a score bonus
	{
		if (!bonusOn)
		{
			bonusOn = true;
			bonus.x = bug[i].x;
			bonus.y = bug[i].y;
		}
	}
	else							// with probability 1/3 leave a life bonus
	{
		if (!lifeOn)
		{
			lifeOn = true;
			life.x = bug[i].x;
			life.y = bug[i].y;
		}
	}
}


///////////////////////////////////////////////////////////////

void Draw_Blocks(void)
{
	// this function draws all the blocks in row major form
	int x1 = BLOCK_ORIGIN_X, // used to track current position
		y1 = BLOCK_ORIGIN_Y; 

	DD_Fill_Surface(lpddsBG, 0);	// clear background
	// draw all the blocks
	for (int row = 0; row < NUM_BLOCK_ROWS; row++)
	{    
		x1 = BLOCK_ORIGIN_X;	// reset column position
		for (int col = 0; col < NUM_BLOCK_COLUMNS; col++)	// draw this row of blocks
		{
			if (blocks[col][row] != FREE)					// draw next block (if there is one)
				Draw_Rectangle(x1, y1, x1 + BLOCK_WIDTH, y1 + BLOCK_HEIGHT,	blocks[col][row], lpddsBG);
			x1 += BLOCK_WIDTH;	// advance column position
		}
		y1 += BLOCK_HEIGHT;		// advance to next row position
	}

	for (int i = 0; i < livesLeft; i++)
	{
		x = 500 + i * (BLOCK_WIDTH + 2);
		y = SCREEN_HEIGHT-15;
		DDraw_Draw_Surface(lpddsHeart, x, y, BLOCK_WIDTH, BLOCK_HEIGHT, lpddsBG);
	}
} // end Draw_Blocks


///////////////////////////////////////////////////////////////

void Init_Blocks(void)
{
	// initialize the block field
	for (int row = 0; row < NUM_BLOCK_ROWS; row++)
		for (int col = 0; col < NUM_BLOCK_COLUMNS; col++)
			if (row == 0 || row == 1
						 || row == (NUM_BLOCK_ROWS - 1)
						 || row == (NUM_BLOCK_ROWS - 2)
						 || col == 0 || col == 1
						 || col == (NUM_BLOCK_COLUMNS - 1)
						 || col == (NUM_BLOCK_COLUMNS - 2))
			{
				blocks[col][row] = OCCUPIED;
				numOccupied++;					// count how many are occupied
			}
			else
				blocks[col][row] = FREE;

	Draw_Blocks();

} // end Init_Blocks


///////////////////////////////////////////////////////////////

int Game_Main(void *parms)
{
	// this is the workhorse of your game it will be called
	// continuously in real-time this is like main() in C
	// all the calls for you game go here!

	int i;								// general-purpose counter

	// what state is the game in? 
	if (game_state == GAME_STATE_INIT)
	{
		srand(Start_Clock());	// seed the random number generator so game is different each play
		DD_Init(SCREEN_WIDTH, SCREEN_HEIGHT, SCREEN_BPP);	// initialize graphics
		score = 0;				// initialize the score
		numBugs = 1;
		numSpiders = 1;
		livesLeft = 5;
		game_state = GAME_STATE_START_LEVEL;				// transition to start level state
	} // end if 

	////////////////////////////////////////////////////////////////
	else
	if (game_state == GAME_STATE_START_LEVEL)
	{
		// get a new level ready to run
		
		numOccupied = 0;					// reset block counter
		bonusOn = false;					// no bonuses displayed
		lifeOn = false;
		initLivesLeft = livesLeft;
		initScore = score;

		// define initially occupied blocks and count them
		Init_Blocks();
		Draw_Blocks();	// create background picture

		ball_x = NUM_BLOCK_COLUMNS / 2;		// set ball position
		ball_y = 0;

		// the percentage of occupied blocks
		percentOccupied = (numOccupied * 100) / NUM_BLOCKS;

		for (i = 0; i < numBugs; i++)		// set bugs' positions and speeds
		{
			bug[i].x = BUG_START_X + rand() % 21 - 10;
			bug[i].y = BUG_START_Y + rand() % 21 - 10;

			bug[i].dx = bug[i].dy = 1;
			if ((rand() % 2) == 0)
				bug[i].dx = -1;
			if ((rand() % 2) == 0)
				bug[i].dy = -1;

			bug[i].frame = rand() % NUM_BUG_FRAMES;
		}

		for (i = 0; i < numSpiders; i++)		// set spiders' positions and speeds
		{
			spider[i].x = rand() % NUM_BLOCK_COLUMNS;
			spider[i].y = NUM_BLOCK_ROWS - 1 - rand() % 2;

			spider[i].dx = spider[i].dy = 1;
			if ((rand() % 2) == 0)
				spider[i].dx = -1;
			if ((rand() % 2) == 0)
				spider[i].dy = -1;
		}

		bonus.frame = 0;
		life.frame = 0;
		game_state = GAME_STATE_RUN;		// transition to run state
		DMusic_Play(midiID[level]);

	} // end if

	///////////////////////////////////////////////////////////////
	else
	if (game_state == GAME_STATE_RUN)
	{
		Start_Clock();			// start the timing clock

		// clear drawing surface for the next frame of animation
		Draw_Rectangle(0,0,SCREEN_WIDTH - 1, SCREEN_HEIGHT - 1,200);

		if (!trail)				// store last coordinates before drawing a trail
		{
			ballXOrig = ball_x;
			ballYOrig = ball_y;
		}
		
		if (KEY_DOWN(VK_RIGHT))	// process keyboard commands
		{
			if (blocks[ball_x][ball_y] == FREE)	// leave trail at previous position
				blocks[ball_x][ball_y] = TRAIL;
			ball_x++;							// move to the right
 			if (ball_x > (NUM_BLOCK_COLUMNS - 1))	// don't let the ball fly away
				ball_x = NUM_BLOCK_COLUMNS - 1;
			if (blocks[ball_x][ball_y] == FREE)
				trail = true;					// currently outside occupied area
		}
		else if (KEY_DOWN(VK_LEFT))
		{
			if (blocks[ball_x][ball_y] == FREE)	// leave trail at previous position
				blocks[ball_x][ball_y] = TRAIL;
			ball_x--;
 			if (ball_x < 0)
				ball_x = 0;
			if (blocks[ball_x][ball_y] == FREE)
				trail = true;					// currently outside occupied area
		}
		else if (KEY_DOWN(VK_UP))
		{
			if (blocks[ball_x][ball_y] == FREE)	// leave trail at previous position
				blocks[ball_x][ball_y] = TRAIL;
			ball_y--;
			if (ball_y < 0)
				ball_y = 0;
			if (blocks[ball_x][ball_y] == FREE)
				trail = true;					// currently outside occupied area
		}
		else if (KEY_DOWN(VK_DOWN))
		{
			if (blocks[ball_x][ball_y] == FREE)	// leave trail at previous position
				blocks[ball_x][ball_y] = TRAIL;
			ball_y++;
			if (ball_y > (NUM_BLOCK_ROWS - 1))
				ball_y = NUM_BLOCK_ROWS - 1;
			if (blocks[ball_x][ball_y] == FREE)
				trail = true;					// currently outside occupied area
		}

		
		if (blocks[ball_x][ball_y] == TRAIL)	// punish for ball crossing it's own trail
		{
			ball_x = ballXOrig;
			ball_y = ballYOrig;
			score -= 200;
			livesLeft--;
			ClearTrail();
			trail = false;
			Draw_Blocks();
			DSound_Play(sound[DEATH_SOUND]);
		}

		for (i = 0; i < numBugs; i++)				// for all bugs
		{
			if (blocks[bug[i].x + bug[i].dx][bug[i].y] == OCCUPIED) //test next block
				bug[i].dx = -bug[i].dx;				// reverse direction if on boundary
			bug[i].x += bug[i].dx;					// move the bugs
			if (blocks[bug[i].x][bug[i].y + bug[i].dy] == OCCUPIED)
				bug[i].dy = -bug[i].dy;
			bug[i].y += bug[i].dy;

			if (ball_x == bug[i].x && ball_y == bug[i].y)	// punish for letting a bug hit the ball
			{
				ball_x = ballXOrig;
				ball_y = ballYOrig;
				score -= 150;
				livesLeft--;
				ClearTrail();
				trail = false;
				Draw_Blocks();
				DSound_Play(sound[DEATH_SOUND]);
			}
			
			if (blocks[bug[i].x][bug[i].y] == TRAIL)		// punish for letting a bug cross your trail
			{
				ball_x = ballXOrig;
				ball_y = ballYOrig;
				score -= 100;
				livesLeft--;
				ClearTrail();
				trail = false;
				Draw_Blocks();
				DSound_Play(sound[DEATH_SOUND]);
			}

			if (bonusOn && bonus.x == bug[i].x && bonus.y == bug[i].y)	// bug picks up the bonus
				bonusOn = false;
			if (lifeOn && life.x == bug[i].x && life.y == bug[i].y)		// bug picks up the life
				lifeOn = false;
		}

		moveCounter = (moveCounter + 1) % 4;				// move the spiders every 4th cycle
		for (i = 0; i < numSpiders; i++)					// for all spiders
		{
			if (!moveCounter)
			{
				x = spider[i].x + spider[i].dx;				// look for horizontal boundaries
				if (blocks[x][spider[i].y] != OCCUPIED		// test next block
							|| x >= NUM_BLOCK_COLUMNS
							|| x < 0)
					spider[i].dx = -spider[i].dx;			// reverse direction if on boundary
				spider[i].x += spider[i].dx;

				y = spider[i].y + spider[i].dy;
				if (blocks[spider[i].x][y] != OCCUPIED		// same for vertical direction
							|| y >= NUM_BLOCK_ROWS
							|| y < 0)
					spider[i].dy = -spider[i].dy;
				spider[i].y += spider[i].dy;

				if (ball_x == spider[i].x && ball_y == spider[i].y)	// punish for letting a spider hit the ball
				{
					ball_x = ballXOrig;
					ball_y = ballYOrig;
					score -= 150;
					livesLeft--;
					ClearTrail();
					trail = false;
					Draw_Blocks();
					DSound_Play(sound[DEATH_SOUND]);
				}

				if (bonusOn && bonus.x == spider[i].x && bonus.y == spider[i].y)	// spider destroys bonus
					bonusOn = false;
				if (lifeOn && life.x == spider[i].x && life.y == spider[i].y)		// spider destroys life bonus
					lifeOn = false;
			}
		}

		// process bonus
		if (bonusOn && ball_x == bonus.x && ball_y == bonus.y)
		{
			bonusOn = false;
			score += 500;
			DSound_Play(sound[BONUS_SOUND]);
		}
		if (lifeOn && ball_x == life.x && ball_y == life.y)
		{
			livesLeft = (livesLeft >= 10) ?  10 : livesLeft + 1;
			lifeOn = false;
			DSound_Play(sound[BONUS_SOUND]);
		}

		// returned to occupied territory - fill it
		if (trail && blocks[ball_x][ball_y] == OCCUPIED)
		{
			FillOccupied();
			trail = false;
			percentOccupied = (numOccupied * 100) / NUM_BLOCKS;
			if (percentOccupied > 80)
			{
				game_state = GAME_STATE_WIN;
				DSound_Play(sound[WIN_SOUND]);
				score += 1000;		// give player 1000 points for completing the level
			}
			Draw_Blocks();
		}

		// generate a bonus
		if (!(rand() % 1000))		// once in 1000 times
			GenerateBonuses();

		DrawEverything();

		DD_Flip();					// flip the surfaces

		Wait_Clock(idleTime);		// sync to 33ish fps

		if (!livesLeft)
			game_state = GAME_STATE_LOSE;

		if (DMusic_Status_MIDI(midiID[level]) == MIDI_STOPPED)	// make sure the music's playing
			DMusic_Play(midiID[level]);
		
		if (KEY_DOWN(VK_ESCAPE))								// check of user is trying to exit
		{
		   PostMessage(main_window_handle, WM_DESTROY,0,0);		// send message to windows to exit
		   game_state = GAME_STATE_SHUTDOWN;					// set exit state
		}

		if (KEY_DOWN(VK_SPACE))						// restart the level when SPACE pressed
		{
			livesLeft = initLivesLeft;				// give the player the original number of lives
			score = initScore;						// give the player the original score
			game_state = GAME_STATE_START_LEVEL;
		}

		if (KEY_DOWN(VK_PAUSE))						// pause the game when PAUSE pressed
			game_state = GAME_STATE_PAUSE;
	} // end if
	///////////////////////////////////////////////////////////////
	else
	if (game_state == GAME_STATE_WIN)
	{
		moveCounter = (moveCounter + 1) % 4;

		DrawEverything();

		sprintf(buffer,"Score: %d    Level: %d    Occupied=%d",
										score, level, percentOccupied);
		Draw_Text_GDI(buffer, SCREEN_WIDTH / 4 + 20, SCREEN_HEIGHT / 2, 255);
		sprintf(buffer, "Press SPACE to continue");
		Draw_Text_GDI(buffer, SCREEN_WIDTH / 4 + 65, SCREEN_HEIGHT / 2 + 50, 255);
		sprintf(buffer, "Press ESCAPE to quit");
		Draw_Text_GDI(buffer, SCREEN_WIDTH / 4 + 75, SCREEN_HEIGHT / 2 + 100, 255);

		DD_Flip();			// flip the surfaces once


		if (DMusic_Status_MIDI(midiID[0]) == MIDI_STOPPED)			// loop midi file
			DMusic_Play(midiID[0]);

		if (DMusic_Status_MIDI(midiID[level]) == MIDI_PLAYING)		// stop previous midi music
			DMusic_Stop(midiID[level]);

		if (KEY_DOWN(VK_SPACE))
		{
			game_state = GAME_STATE_START_LEVEL;
			numBugs = numBugs + 1 % NUM_LEVELS;
			numSpiders = (numBugs + 1) / 2;
			DMusic_Stop(midiID[0]);
			level = numBugs;
			flipped = false;
		}

		if (KEY_DOWN(VK_ESCAPE))
		{
		   PostMessage(main_window_handle, WM_DESTROY,0,0);	// send message to windows to exit
		   game_state = GAME_STATE_SHUTDOWN;				// set exit state
		}

		Wait_Clock(idleTime);
	}
	///////////////////////////////////////////////////////////////
	else
	if (game_state == GAME_STATE_PAUSE)
	{
		moveCounter = (moveCounter + 1) % 4;

		DrawEverything();

		sprintf(buffer, "PAUSE");
		Draw_Text_GDI(buffer, SCREEN_WIDTH / 2 - 20, SCREEN_HEIGHT / 2, 255);
		sprintf(buffer,"Press ENTER to continue");
		Draw_Text_GDI(buffer, SCREEN_WIDTH / 2 - 80, SCREEN_HEIGHT / 2 + 50, 255);

		DD_Flip();

		if (DMusic_Status_MIDI(midiID[NUM_LEVELS + 1]) == MIDI_STOPPED)	// loop midi file
			DMusic_Play(midiID[NUM_LEVELS + 1]);

		if (DMusic_Status_MIDI(midiID[level]) == MIDI_PLAYING)			// stop previous midi music
			DMusic_Stop(midiID[level]);

		if (KEY_DOWN(VK_RETURN))							// pressing enter button
		{
			game_state = GAME_STATE_RUN;					// takes game off pause
			DMusic_Stop(midiID[NUM_LEVELS + 1]);
		}

		if (KEY_DOWN(VK_ESCAPE))
		{
		   PostMessage(main_window_handle, WM_DESTROY,0,0);	// send message to windows to exit
		   game_state = GAME_STATE_SHUTDOWN;				// set exit state
		}

		Wait_Clock(idleTime);
	}
	///////////////////////////////////////////////////////////////
	else
	if (game_state == GAME_STATE_LOSE)
	{
		moveCounter = (moveCounter + 1) % 4;

		DrawEverything();

		sprintf(buffer,"Score: %d    Level: %d    Occupied=%d",
										score, level, percentOccupied);
		Draw_Text_GDI(buffer, SCREEN_WIDTH / 4 + 20, SCREEN_HEIGHT / 2, 255);
		sprintf(buffer, "Press SPACE to start over");
		Draw_Text_GDI(buffer, SCREEN_WIDTH / 4 + 60, SCREEN_HEIGHT / 2 + 50, 255);
		sprintf(buffer, "Press ESCAPE to quit");
		Draw_Text_GDI(buffer, SCREEN_WIDTH / 4 + 75, SCREEN_HEIGHT / 2 + 100, 255);

		DD_Flip();			// flip the surfaces once


		if (DMusic_Status_MIDI(midiID[0]) == MIDI_STOPPED)		// loop midi file
			DMusic_Play(midiID[0]);

		if (DMusic_Status_MIDI(midiID[level]) == MIDI_PLAYING)	// stop previous midi music
			DMusic_Stop(midiID[level]);

		if (KEY_DOWN(VK_SPACE))
		{
			game_state = GAME_STATE_INIT;
			DMusic_Stop(midiID[0]);
		}

		if (KEY_DOWN(VK_ESCAPE))
		{
		   PostMessage(main_window_handle, WM_DESTROY,0,0);	// send message to windows to exit
		   game_state = GAME_STATE_SHUTDOWN;				// set exit state
		}

		Wait_Clock(idleTime);
	}
	///////////////////////////////////////////////////////////////
	else
	if (game_state == GAME_STATE_SHUTDOWN)
	{
		DarkenScreen();
		DD_Shutdown();	// in this state shut everything down and release resources
		game_state = GAME_STATE_EXIT;	// switch to exit state
	}
	return(1);			// return success

} // end Game_Main

///////////////////////////////////////////////////////////////


void DrawEverything()
{
	int i;								// general-purpose counter

	// draw blocks (background)
	DDraw_Draw_Surface(lpddsBG, 0, 0, WINDOW_WIDTH, WINDOW_HEIGHT, lpddsback, 0);

	// draw the ball
	x = ball_x * BLOCK_WIDTH;
	y = ball_y * BLOCK_HEIGHT;
	DDraw_Draw_Surface(lpddsBall, x, y, BLOCK_WIDTH, BLOCK_HEIGHT, lpddsback);

	// draw the trail
	if (trail)
		Draw_Rectangle(x, y, x + BLOCK_WIDTH, y + BLOCK_HEIGHT, TRAIL, lpddsBG);

	// draw the bonuses
	if (bonusOn)
	{
		x = bonus.x * BLOCK_WIDTH;
		y = bonus.y * BLOCK_HEIGHT;
		DDraw_Draw_Surface(lpddsBonus[bonus.frame], x, y, BLOCK_WIDTH, BLOCK_HEIGHT, lpddsback);
		if (!moveCounter)
			bonus.frame = (bonus.frame + 1) % NUM_BONUS_FRAMES;
	}
	if (lifeOn)
	{
		x = life.x * BLOCK_WIDTH;
		y = life.y * BLOCK_HEIGHT;
		DDraw_Draw_Surface(lpddsLife[life.frame], x, y, BLOCK_WIDTH, BLOCK_HEIGHT, lpddsback);
		if (!moveCounter)
			life.frame = (life.frame + 1) % NUM_LIFE_FRAMES;
	}

	// draw the bugs
	for (i = 0; i < numBugs; i++)
	{
		x = bug[i].x * BLOCK_WIDTH;
		y = bug[i].y * BLOCK_HEIGHT;
		DDraw_Draw_Surface(lpddsBug[bug[i].frame], x, y, BLOCK_WIDTH, BLOCK_HEIGHT, lpddsback);
		if (moveCounter % 2)
			bug[i].frame = (bug[i].frame + 1) % NUM_BUG_FRAMES;
	}

	// draw the spiders
	for (i = 0; i < numSpiders; i++)
	{
		x = spider[i].x * BLOCK_WIDTH;
		y = spider[i].y * BLOCK_HEIGHT;
		DDraw_Draw_Surface(lpddsSpider, x, y, BLOCK_WIDTH, BLOCK_HEIGHT, lpddsback);
	}

	frames++;				// count FPS
	if (GetTickCount() - startTime > 1000)
	{
		fps = (int)frames;
		frames = 0;
		startTime = GetTickCount();
	}

	// draw the info
	sprintf(buffer, "X O N I X    Score %d    Level %d    %d fps    Occupied=%d    Lives:",
									score, level, fps, percentOccupied);
	Draw_Text_GDI(buffer, 8, SCREEN_HEIGHT-15, 235);
}
